@@ -61,6 +61,10 @@
 #define gtk_vbox_new(X,Y) gtk_box_new(GTK_ORIENTATION_VERTICAL,Y)
 #endif
 
+#if !GTK_CHECK_VERSION(3,0,0)
+#define gtk_widget_get_preferred_size(x,y,z) gtk_widget_size_request(x,y)
+#endif
+
 enum
 {
   COMPLETION_TEXT_COLUMN,
@@ -1611,6 +1615,7 @@ gdict_window_size_allocate (GtkWidget     *widget,
 		    						 allocation);
 }
 
+#if !GTK_CHECK_VERSION (3, 0, 0)
 static void
 set_window_default_size (GdictWindow *window)
 {
@@ -1628,8 +1633,8 @@ set_window_default_size (GdictWindow *window)
   widget = GTK_WIDGET (window);
 
   /* make sure that the widget is realized */
+  /*Do this implicitly in GTK3.21 or segfault results */
   gtk_widget_realize (widget);
-  
   /* XXX - the user wants mate-dictionary to resize itself, so
    * we compute the minimum safe geometry needed for displaying
    * the text returned by a dictionary server, which is based
@@ -1650,7 +1655,7 @@ set_window_default_size (GdictWindow *window)
       height = font_size * GDICT_WINDOW_ROWS;
 
       /* Use at least the requisition size of the window... */
-      gtk_widget_size_request (widget, &req);
+      gtk_widget_get_preferred_size (widget, NULL, &req);
       width = MAX (width, req.width);
       height = MAX (height, req.height);
 
@@ -1685,7 +1690,7 @@ gdict_window_style_set (GtkWidget *widget,
 
   set_window_default_size (GDICT_WINDOW (widget));
 }
-
+#endif
 static void
 gdict_window_handle_notify_position_cb (GtkWidget  *widget,
 					GParamSpec *pspec,
@@ -1732,7 +1737,9 @@ gdict_window_constructor (GType                  type,
   /* recover the state */
   gdict_window_load_state (window);
 
+#if !GTK_CHECK_VERSION(3,0,0)
   gtk_widget_push_composite_child ();
+#endif
  
   window->main_box = gtk_vbox_new (FALSE, 0);
   gtk_container_add (GTK_CONTAINER (window), window->main_box);
@@ -2006,7 +2013,9 @@ gdict_window_constructor (GType                  type,
 
   gtk_widget_grab_focus (window->entry);
 
+#if !GTK_CHECK_VERSION(3,0,0)
   gtk_widget_pop_composite_child ();
+#endif
 
   window->in_construction = FALSE;
 
@@ -2108,7 +2117,9 @@ gdict_window_class_init (GdictWindowClass *klass)
                                      LAST_PROP,
                                      gdict_window_properties);
 
+#if !GTK_CHECK_VERSION (3, 0, 0)
   widget_class->style_set = gdict_window_style_set;
+#endif
   widget_class->size_allocate = gdict_window_size_allocate;
 }
 
